==> wurld-0.3.tar.gz: wurld-0.3/src/util.py <==
#==============================================================================
#
#  $Id$
#
"""
   Some basic utilities.
"""
#
#  Copyright (C) 2007 Michael A. Muller
#
#  Permission is granted to use, modify and redistribute this code,
#  providing that the following conditions are met:
#
#  1) This copyright/licensing notice must remain intact.
#  2) If the code is modified and redistributed, the modifications must 
#  include documentation indicating that the code has been modified.
#  3) The author(s) of this code must be indemnified and held harmless
#  against any damage resulting from the use of this code.
#
#  This code comes with ABSOLUTELY NO WARRANTEE, not even the implied 
#  warrantee of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
#
#==============================================================================

import wurld

def vecToStr(vec):
   return '(%g, %g, %g)' % (vec.x, vec.y, vec.z)

class Sprite(object):

   COL_NONE = None
   COL_POINT = wurld.createPointCollisionAlgo()

   def __init__(self, model = None, origin = None, velocity = None, 
                collisionAlgo = COL_NONE):
      self.__moveable = wurld.createMoveable()
      self.__pythonObject = wurld.createPythonObject()
      self.__pythonObject.setMoveable(self.__moveable)

      self.__model = None
      if model:
         self.model = model

      if origin:
         self.origin = origin

      self.__registered = False
      if velocity:
         self.velocity = velocity

      if collisionAlgo:
         self.__moveable.setCollisionAlgo(collisionAlgo)

   def __getModel(self):
      return self.__model

   def __setModel(self, model):
      if not self.__model:
         wurld.getGameEngine().addRenderableObject(self.__pythonObject)
      self.__model = model
      self.__moveable.setModel(model)

   model = property(__getModel, __setModel, None, "the associated model")

   def __getOrigin(self):
      return self.__moveable.getPosition()

   def __setOrigin(self, pos):
      self.__moveable.setPosition(pos)

   def __register(self):
      "Register for callbacks with the game engine if we are not already"
      if not self.__registered:
         # once velocity gets set, we need to become an engine object so that
         # motion starts happening
         self.__registered = True
         wurld.getGameEngine().addGameObject(self.__pythonObject)

   origin = property(__getOrigin, __setOrigin, None, 
                     "the position of the model")

   def __getVelocity(self):
      return self.__moveable.getVelocity()

   def __setVelocity(self, velocity):
      self.__register()
      self.__moveable.setVelocity(velocity)

   velocity = property(__getVelocity, __setVelocity, None, 
                       "the velocity of the object"
                       )

   def __getRotation(self):
      return self.__moveable.getRotation()

   def __setRotation(self, rot):
      self.__moveable.setRotation(rot)

   rotation = property(__getRotation, __setRotation, None,
                       "the object's rotation"
                       )

   def __setEngineFrameCallback(self, callback):
      self.__register()
      self.__pythonObject.setEngineFrameCallback(callback)

   engineFrameCallback = property(None, __setEngineFrameCallback, None,
                                  "Function to be called every engine frame"
                                  )

   def __setRenderFrameCallback(self, callback):
      self.__register()
      self.__pythonObject.setRenderFrameCallback(callback)

   renderFrameCallback = property(None, __setRenderFrameCallback, None,
                                  "Function to be called every render frame "
                                   "(use sparingly - potential speed issues)"
                                  )

   def __setCollisionCallback(self, callback):
      self.__pythonObject.setCollisionCallback(callback)

   collisionCallback = property(None, __setCollisionCallback, None,
                                "Function to be called whenever there is a "
                                 "collision"
                                )

   def addCollidable(self, collidable):
      self.__moveable.addCollidable(collidable)
      wurld.getGameEngine().addCollidable(collidable)

   def enableTrace(self, trace):
      self.__moveable.enableTrace(trace)

def showModel(model):
   """
      Wraps the model in a moveable and a python object and adds it to the
      renderables.
   """
   moveable = wurld.createMoveable()
   moveable.setModel(model)
   obj = wurld.createPythonObject()
   obj.setMoveable(moveable)
   wurld.getGameEngine().addRenderableObject(obj)
   return obj

class Rot:
   """
      A class to make dealing with rotation matrices a little less verbose.
   """

   def __init__(self, rotMatrix):
      self.mtx = rotMatrix

   @staticmethod
   def yaw(deg):
      return Rot(wurld.createYawRotMatrix(deg))

   @staticmethod
   def pitch(deg):
      return Rot(wurld.createPitchRotMatrix(deg))

   @staticmethod
   def roll(deg):
      return Rot(wurld.createRollRotMatrix(deg))

   def __mul__(self, other):
      temp = Rot.yaw(0)
      temp.mtx.makeProduct(self.mtx, other.mtx)
      return temp

   def rotate(self, vector):
      temp = wurld.createVector(0, 0, 0)
      self.mtx.rotate(vector, temp)
      return temp

class TextPane:

   def __init__(self, x, y, width, height):
      self.x = x
      self.y = y
      self.width = width
      self.height = height
      self.__obj = wurld.createSimpleText("", x, y, width, height)
      wurld.getGameEngine().addHUDSticker(self.__obj)
      self.__buffer = ''

   def __del__(self):
      wurld.getGameEngine().removeHUDSticker(self.__obj)

   def write(self, text):
      self.__buffer += text

      # replace the existing simple text object with a new one
      engine = wurld.getGameEngine()
      engine.removeHUDSticker(self.__obj)
      self.__obj = \
         wurld.createSimpleText(self.__buffer, self.x, self.y,
                                self.width, 
                                self.height
                                )
      engine.addHUDSticker(self.__obj)

==> wurld-0.4.tar.gz: wurld-0.4/src/util.py <==
#==============================================================================
#
#  $Id$
#
"""
   Some basic utilities.
"""
#
#  Copyright (C) 2007 Michael A. Muller
#
#  Permission is granted to use, modify and redistribute this code,
#  providing that the following conditions are met:
#
#  1) This copyright/licensing notice must remain intact.
#  2) If the code is modified and redistributed, the modifications must 
#  include documentation indicating that the code has been modified.
#  3) The author(s) of this code must be indemnified and held harmless
#  against any damage resulting from the use of this code.
#
#  This code comes with ABSOLUTELY NO WARRANTEE, not even the implied 
#  warrantee of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
#
#==============================================================================

import wurld

def vecToStr(vec):
   return '(%g, %g, %g)' % (vec.x, vec.y, vec.z)

class Sprite(object):

   COL_NONE = None
   COL_POINT = wurld.createPointCollisionAlgo()

   def __init__(self, model = None, origin = None, velocity = None, 
                collisionAlgo = COL_NONE):
      self.__moveable = wurld.createMoveable()
      self.__pythonObject = wurld.createPythonObject()
      self.__pythonObject.setMoveable(self.__moveable)

      self.__model = None
      if model:
         self.model = model

      if origin:
         self.origin = origin

      self.__registered = False
      if velocity:
         self.velocity = velocity

      if collisionAlgo:
         self.__moveable.setCollisionAlgo(collisionAlgo)

   def __getModel(self):
      return self.__model

   def __setModel(self, model):
      if not self.__model:
         wurld.getGameEngine().addRenderableObject(self.__pythonObject)
      self.__model = model
      self.__moveable.setModel(model)

   model = property(__getModel, __setModel, None, "the associated model")

   def __getOrigin(self):
      return self.__moveable.getPosition()

   def __setOrigin(self, pos):
      self.__moveable.setPosition(pos)

   def __register(self):
      "Register for callbacks with the game engine if we are not already"
      if not self.__registered:
         # once velocity gets set, we need to become an engine object so that
         # motion starts happening
         self.__registered = True
         wurld.getGameEngine().addGameObject(self.__pythonObject)

   origin = property(__getOrigin, __setOrigin, None, 
                     "the position of the model")

   def __getVelocity(self):
      return self.__moveable.getVelocity()

   def __setVelocity(self, velocity):
      self.__register()
      self.__moveable.setVelocity(velocity)

   velocity = property(__getVelocity, __setVelocity, None, 
                       "the velocity of the object"
                       )

   def __getRotation(self):
      return self.__moveable.getRotation()

   def __setRotation(self, rot):
      self.__moveable.setRotation(rot)

   rotation = property(__getRotation, __setRotation, None,
                       "the object's rotation"
                       )

   def __getMoveable(self):
      return self.__moveable

   moveable = property(__getMoveable, None, None, 'the associated "Moveable"')

   def __setEngineFrameCallback(self, callback):
      self.__register()
      self.__pythonObject.setEngineFrameCallback(callback)

   engineFrameCallback = property(None, __setEngineFrameCallback, None,
                                  "Function to be called every engine frame"
                                  )

   def __setRenderFrameCallback(self, callback):
      self.__register()
      self.__pythonObject.setRenderFrameCallback(callback)

   renderFrameCallback = property(None, __setRenderFrameCallback, None,
                                  "Function to be called every render frame "
                                   "(use sparingly - potential speed issues)"
                                  )

   def __setCollisionCallback(self, callback):
      self.__pythonObject.setCollisionCallback(callback)

   collisionCallback = property(None, __setCollisionCallback, None,
                                "Function to be called whenever there is a "
                                 "collision"
                                )

   def addCollidable(self, collidable):
      self.__moveable.addCollidable(collidable)
      wurld.getGameEngine().addCollidable(collidable)

   def enableTrace(self, trace):
      self.__moveable.enableTrace(trace)

def showModel(model):
   """
      Wraps the model in a moveable and a python object and adds it to the
      renderables.
   """
   moveable = wurld.createMoveable()
   moveable.setModel(model)
   obj = wurld.createPythonObject()
   obj.setMoveable(moveable)
   wurld.getGameEngine().addRenderableObject(obj)
   return obj

class Rot:
   """
      A class to make dealing with rotation matrices a little less verbose.
   """

   def __init__(self, rotMatrix):
      self.mtx = rotMatrix

   @staticmethod
   def yaw(deg):
      return Rot(wurld.createYawRotMatrix(deg))

   @staticmethod
   def pitch(deg):
      return Rot(wurld.createPitchRotMatrix(deg))

   @staticmethod
   def roll(deg):
      return Rot(wurld.createRollRotMatrix(deg))

   def __mul__(self, other):
      temp = Rot.yaw(0)
      temp.mtx.makeProduct(self.mtx, other.mtx)
      return temp

   def rotate(self, vector):
      temp = wurld.createVector(0, 0, 0)
      self.mtx.rotate(vector, temp)
      return temp

class TextPane:

   def __init__(self, x, y, width, height, background = None):
      self.x = x
      self.y = y
      self.width = width
      self.height = height
      self.__obj = wurld.createSimpleText("", x, y, width, height)
      self.__buffer = ''
      if background:
         self.__bg = wurld.createQuadPane(x, y, width, height, background)
         wurld.getGameEngine().addHUDSticker(self.__bg)
      else:
         self.__bg = None
      wurld.getGameEngine().addHUDSticker(self.__obj)

   def __del__(self):
      wurld.getGameEngine().removeHUDSticker(self.__obj)
      if self.__bg:
         wurld.getGameEngine().removeHUDSticker(self.__bg)

   def write(self, text):
      self.__buffer += text

      # replace the existing simple text object with a new one
      engine = wurld.getGameEngine()
      engine.removeHUDSticker(self.__obj)
      self.__obj = \
         wurld.createSimpleText(self.__buffer, self.x, self.y,
                                self.width, 
                                self.height
                                )
      engine.addHUDSticker(self.__obj)
